==> xcfa_3.4.1.orig.tar.gz: xcfa-3.4.1/src/popup.h <==
 /*
 * file      : popup.h
 * project   : xcfa
 * with      : Gtk-2
 *
 * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
 *
 * xcfa - GTK+ implementation of the GNU shell command
 * GNU General Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * OLD ADRESS:
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * NEW ADRESS:
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */
 
 
#ifndef __popup_h__
#define __popup_h__ 1


void popup_for_pocheevent (gboolean bool_recto);

void popup_cd (AUDIO *Audio, TYPE_FILE_IS TypeFileIs);
void popup_normalise_cd (void);
void popup_normalise_dvd (void);
void popup_file (DETAIL *detail, TYPE_FILE_IS TypeFileIs);
/*void popup_file_Normalisation (DETAIL *detail, gboolean BoolAllIsNormalised, gboolean BoolIsSelected);*/
void popup_file_ReplayGain (DETAIL *detail);
void popup_make_popup_TST (void);
void popup_trash (void);
void popup_frequence (void);
void popup_piste (void);
void popup_quantification (void);



#endif

==> xcfa_4.0.0.orig.tar.gz: xcfa-4.0.0/src/popup.h <==
 /*
 * file      : popup.h
 * project   : xcfa
 * with      : Gtk-2
 *
 * copyright : (C) 2003 - 2010 by Claude Bulin
 *
 * xcfa - GTK+ implementation of the GNU shell command
 * GNU General Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * OLD ADRESS:
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * NEW ADRESS:
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */
 
 
#ifndef popup_h
#define popup_h 1

#include "file.h"
#include "cd_audio.h"

void	popup_normalise_dvd (void);

void	popup_cd (AUDIO *Audio, TYPE_FILE_IS TypeFileIs);
void	popup_normalise_cd (void);

void	popup_trash (void);
void	popup_file (DETAIL *detail, TYPE_FILE_IS TypeFileIs);
void	popup_file_ReplayGain (DETAIL *detail);

void	popup_file_wav_frequence (DETAIL *detail);
void	popup_file_wav_piste (DETAIL *detail);
void	popup_file_wav_quantification (DETAIL *detail);

void	popup_file_Split (void);

void	popup_for_pocheevent (gboolean bool_recto);

#endif
